import { z } from 'zod';

// 授权请求验证模式
export const authorizationRequestSchema = z.object({
    response_type: z.union([
        z.literal('code'),                 // 授权码流程
        z.literal('token'),                // 隐式流程 - 仅访问令牌
        z.literal('id_token'),             // 隐式流程 - 仅ID令牌
        z.literal('token id_token'),       // 隐式流程 - 访问令牌和ID令牌
        z.literal('code id_token'),        // 混合流程 - 授权码和ID令牌
        z.literal('code token'),           // 混合流程 - 授权码和访问令牌
        z.literal('code token id_token'),  // 混合流程 - 授权码、访问令牌和ID令牌
    ]),
    client_id: z.string(),
    redirect_uri: z.string().url('必须是有效的URL'),
    state: z.string().optional(),
    scope: z.string(),
    code_challenge: z.string().optional(),
    code_challenge_method: z.enum(['plain', 'S256']).optional(),
    nonce: z.string().optional(),
    prompt: z.enum(['none', 'login', 'consent', 'select_account']).optional(),
    max_age: z.number().optional(),
    response_mode: z.enum(['query', 'fragment', 'form_post']).optional().default('query'),
    session_id: z.string().optional(), // 用于静默授权
});

// 授权码生成参数模式
export const authorizationCodeParamsSchema = z.object({
    userId: z.string(),
    clientId: z.string(),
    redirectUri: z.string().url(),
    scope: z.string(),
    nonce: z.string().optional(),
    codeChallenge: z.string().optional(),
    codeChallengeMethod: z.enum(['plain', 'S256']).optional(),
});

// 类型定义
export type AuthorizationRequest = z.infer<typeof authorizationRequestSchema>;
export type AuthorizationCodeParams = z.infer<typeof authorizationCodeParamsSchema>; 